==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_km.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=km
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'លុបចេញ ស្ថិតិ', # MODIF

	// I
	'icone_evolution_visites' => 'ការវិវត្ត នៃចំណូលមើល<br />@visites@ ចំណូលមើល',
	'icone_repartition_actuelle' => 'បង្ហាញចេញ ​បំណែងចែក​បច្ចុប្បន្ន',
	'icone_repartition_visites' => 'បំណែងចែក ការ​ទស្សនា',
	'icone_statistiques_visites' => 'ស្ថិតិ',
	'info_affichier_visites_articles_plus_visites' => 'បង្ហាញចំណូលមើល សំរាប់ <b>អត្ថបទ ត្រូវបានចូលមើល ច្រើនបំផុត ពីដើម ៖</b>',
	'info_comment_lire_tableau' => 'ធ្វើមេចអាន តារាងនេះ',
	'info_forum_statistiques' => 'ស្ថិតិ ចំណូលមើល',
	'info_popularite_2' => 'ភាពប្រជាប្រិយ នៃសៃថ៍ ៖',
	'info_popularite_3' => 'ភាពប្រជាប្រិយ ៖ @popularite@; ចំណូលមើល ៖ @visites@',
	'info_popularite_5' => 'ប្រជាប្រិយភាព៖',
	'info_visites' => 'ការ​ទស្សនា ៖',
	'info_visites_plus_populaires' => 'បង្ហាញ​ចេញ ​ការ​ទស្សនា​ទាំងឡាយ សំរាប់<b>អត្ថបទ​ដែល​ប្រជាប្រិយ​បំផុត</b> និង​ សំរាប់ <b>អត្ថបទ ត្រូវបានផ្សព្វផ្សាយ ថ្មីៗ ៖</b>',
	'info_zoom' => 'ពង្រីក',
	'item_gerer_statistiques' => 'គ្រប់គ្រង​ស្ថិតិ', # MODIF

	// O
	'onglet_origine_visites' => 'ភាព​ដើម នៃការទស្សនា',
	'onglet_repartition_debut' => 'តាំងពី​ដំបូង',
	'onglet_repartition_lang' => 'បំណែងចែក ​តាមភាសា',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'កំរិត​នៃ​អត្ថបទ នៅ​ក្នុង​ប្រភេទ​ភាព​ពេញ​និយម ត្រូវ​បាន​បង្ហាញ​នៅ​ក្នុង​រឹម​ទំព័រ​។ ភាព​ពេញ​និយម​របស់​អត្ថបទ (​ចំនួន​ប៉ាន់​ប្រមាណ​នៃ​ការ​ទស្សនា​ប្រចាំ​ថ្ងៃ​ដែល​វា​មាន​ប្រសិនបើ​ល្បឿន​ជាក់ស្ដែង​នៃ​ចរាចរ​សេវាកម្ម​ត្រូវ​បាន​រក្សា​) ហើយ​ចំនួន​នៃ​ការ​ទស្សនា​ដែល​កត់ត្រា​តាំងពី​ពេល​ចាប់ផ្ដើម​ត្រូវ​បាន​បង្ហាញ​នៅ​ក្នុង​បា​ឡូង​ដែល​មាន​សភាព​ជា​រូប​សំកាំង​នៅ​លើ​ចំណងជើង​។',
	'texte_signification' => 'របារ​ខ្មៅ​តំណាង​ឱ្យ​ពាក្យ​រួម (​សរុប​នៃ​ផ្នែក​រង​) របារ​មិនសូវ​ដិត​តំណាង​ឱ្យ​ចំនួន​នៃ​ការ​ទស្សនា​របស់​ផ្នែក​នីមួយៗ​។',
	'titre_evolution_visite' => 'ការវិវត្ត នៃចំណូលមើល',
	'titre_liens_entrants' => 'តំណភ្ជាប់ចូល',
	'titre_page_statistiques' => 'ស្ថិតិ តាមផ្នែក',
	'titre_page_statistiques_visites' => 'ស្ថិតិ ចំណូលមើល'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_km.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=km
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'លុបចេញ ស្ថិតិ', # MODIF

	// I
	'icone_evolution_visites' => 'ការវិវត្ត នៃចំណូលមើល<br />@visites@ ចំណូលមើល',
	'icone_repartition_actuelle' => 'បង្ហាញចេញ ​បំណែងចែក​បច្ចុប្បន្ន',
	'icone_repartition_visites' => 'បំណែងចែក ការ​ទស្សនា',
	'icone_statistiques_visites' => 'ស្ថិតិ',
	'info_affichier_visites_articles_plus_visites' => 'បង្ហាញចំណូលមើល សំរាប់ <b>អត្ថបទ ត្រូវបានចូលមើល ច្រើនបំផុត ពីដើម ៖</b>',
	'info_comment_lire_tableau' => 'ធ្វើមេចអាន តារាងនេះ',
	'info_forum_statistiques' => 'ស្ថិតិ ចំណូលមើល',
	'info_popularite_2' => 'ភាពប្រជាប្រិយ នៃសៃថ៍ ៖',
	'info_popularite_3' => 'ភាពប្រជាប្រិយ ៖ @popularite@; ចំណូលមើល ៖ @visites@',
	'info_popularite_5' => 'ប្រជាប្រិយភាព៖',
	'info_visites' => 'ការ​ទស្សនា ៖',
	'info_visites_plus_populaires' => 'បង្ហាញ​ចេញ ​ការ​ទស្សនា​ទាំងឡាយ សំរាប់<b>អត្ថបទ​ដែល​ប្រជាប្រិយ​បំផុត</b> និង​ សំរាប់ <b>អត្ថបទ ត្រូវបានផ្សព្វផ្សាយ ថ្មីៗ ៖</b>',
	'info_zoom' => 'ពង្រីក',
	'item_gerer_statistiques' => 'គ្រប់គ្រង​ស្ថិតិ', # MODIF

	// O
	'onglet_origine_visites' => 'ភាព​ដើម នៃការទស្សនា',
	'onglet_repartition_debut' => 'តាំងពី​ដំបូង',
	'onglet_repartition_lang' => 'បំណែងចែក ​តាមភាសា',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'កំរិត​នៃ​អត្ថបទ នៅ​ក្នុង​ប្រភេទ​ភាព​ពេញ​និយម ត្រូវ​បាន​បង្ហាញ​នៅ​ក្នុង​រឹម​ទំព័រ​។ ភាព​ពេញ​និយម​របស់​អត្ថបទ (​ចំនួន​ប៉ាន់​ប្រមាណ​នៃ​ការ​ទស្សនា​ប្រចាំ​ថ្ងៃ​ដែល​វា​មាន​ប្រសិនបើ​ល្បឿន​ជាក់ស្ដែង​នៃ​ចរាចរ​សេវាកម្ម​ត្រូវ​បាន​រក្សា​) ហើយ​ចំនួន​នៃ​ការ​ទស្សនា​ដែល​កត់ត្រា​តាំងពី​ពេល​ចាប់ផ្ដើម​ត្រូវ​បាន​បង្ហាញ​នៅ​ក្នុង​បា​ឡូង​ដែល​មាន​សភាព​ជា​រូប​សំកាំង​នៅ​លើ​ចំណងជើង​។',
	'texte_signification' => 'របារ​ខ្មៅ​តំណាង​ឱ្យ​ពាក្យ​រួម (​សរុប​នៃ​ផ្នែក​រង​) របារ​មិនសូវ​ដិត​តំណាង​ឱ្យ​ចំនួន​នៃ​ការ​ទស្សនា​របស់​ផ្នែក​នីមួយៗ​។',
	'titre_evolution_visite' => 'ការវិវត្ត នៃចំណូលមើល',
	'titre_liens_entrants' => 'តំណភ្ជាប់ចូល',
	'titre_page_statistiques' => 'ស្ថិតិ តាមផ្នែក',
	'titre_page_statistiques_visites' => 'ស្ថិតិ ចំណូលមើល',

	// V
	'visites' => 'ចំណូលមើល'
);
